http

package
v0.0.0-...-a5daac4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2026 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Transport

type Transport struct {
	// URL is the base URL of the meshtastic API endpoint.
	URL string
	// Client is an HTTP client used to send requests.
	Client http.Client
}

Transport represents a transport mechanism over HTTP for communicating with a Meshtastic device.

func (*Transport) ReceiveFromRadio

func (ht *Transport) ReceiveFromRadio(ctx context.Context) (*proto.FromRadio, error)

ReceiveFromRadio retrieves a protobuf message from the radio through the Meshtastic API.

func (*Transport) SendToRadio

func (ht *Transport) SendToRadio(ctx context.Context, packet *proto.ToRadio) error

SendToRadio sends a protobuf message to the radio through the Meshtastic API.

Jump to